#%%
import re
from collections import Counter
import io_handler
import os
from config import config

class Preprocessor:
    def __init__(self):
        pass
    def clean(self, txt):
        res = re.sub(r'[^\w\s]+', '', txt)
        res = re.sub(r'[\d_\-]+', ' ', res)
        res = re.sub(r'\s+', ' ', res)
        res = re.sub(r'[^ابتةثجحخدذرزسشصضطظعغفقكلمنهويءآأؤإئ\s]+', '', res)
        res = re.sub(r'\s+', ' ', res)
        return res.strip()

    def tokenize(self, txt):
        return txt.split()
    
    def __call__(self, txt):
        ctxt = self.clean(txt)
        txt_arr = self.tokenize(ctxt)
        word_counts = Counter(txt_arr)
        io_handler.save_dict_file(config['vocabs_dict'], dict(word_counts))

    def get_letters(self, txt):
        res = self.clean(txt)
        chars = set(res)
        return chars

text = io_handler.read_txt_file( os.path.dirname(__file__) + '/../data/TXT_No_header.txt')
preprocessor = Preprocessor()
preprocessor(text)

    # %%

# %%



import unittest
from corrector import Corrector

class TestCorrector(unittest.TestCase):
    
    def test_get_most_likely_edit_case1(self):
        edits = [('edit', 1), ('ma', 10), ('df', 20)]
        corr = Corrector()
        expected = 'df'
        res = corr.get_most_likely_edit(edits)
        self.assertEqual(res, expected)
    
    def test_get_most_likely_edit_case2(self):
        edits = [('edit', 10), ('ma', 5), ('df', 2)]
        corr = Corrector()
        expected = 'edit'
        res = corr.get_most_likely_edit(edits)
        self.assertEqual(res, expected)

    def test_get_most_likely_edit_case3(self):
        edits = [('edit', 10), ('ma', 50), ('df', 20)]
        corr = Corrector()
        expected = 'ma'
        res = corr.get_most_likely_edit(edits)
        self.assertEqual(res, expected)


if __name__ == '__main__':
    unittest.main()